/*
 * SPDX-FileCopyrightText: 2015 Luca Beltrame <lbeltrame@kde.org>
 *
 * This file is part of Danbooru Client.
 *
 *SPDX-License-Identifier: GPL-3.0-or-later
 */

#include <QApplication>
#include "danbooru_client_debug.h"
#include <QUrl>
#include <QCommandLineParser>

#include <KLocalizedString>
#include <KAboutData>

#include "mainwindow.h"
#include "danbooru_version.h"
#include "libdanbooru/libdanbooru_version.h"

int main(int argc, char *argv[])
{
    QApplication app(argc, argv);

    QCoreApplication::setApplicationName(QStringLiteral("danbooru-client"));
    QCoreApplication::setApplicationVersion(QStringLiteral(DANBOORU_CLIENT_VERSION_STRING));
    QCoreApplication::setOrganizationDomain(QStringLiteral("dennogumi.org"));
    QApplication::setApplicationDisplayName(i18n("Danbooru Client"));
    KLocalizedString::setApplicationDomain("danbooru-client");

    KAboutData aboutData(I18N_NOOP(QLatin1String("danbooru-client")),
                         i18n("Danbooru Client"),
                         QStringLiteral(DANBOORU_CLIENT_VERSION_STRING),
                         i18n("KF5 based Danbooru client"),
                         KAboutLicense::GPL_V3,
                         i18n("(C) 2015 Luca Beltrame"),
                         QString("Using libdanbooru version %1").arg(LIBDANBOORU_VERSION_STRING),
                         QStringLiteral("https://git.dennogumi.org/kde/danbooru-client"),
                         QStringLiteral("https://git.dennogumi.org/kde/danbooru-client")
                        );

    aboutData.addAuthor(i18n("Luca Beltrame"), i18n("Developer"),
                        QStringLiteral("lbeltrame@kde.org")
                       );

    KAboutData::setApplicationData(aboutData);

    QCommandLineParser cmdParser;
    cmdParser.addHelpOption();
    cmdParser.addVersionOption();
    aboutData.setupCommandLine(&cmdParser);
    cmdParser.process(app);
    aboutData.processCommandLine(&cmdParser);

    Danbooru::DanbooruMainWindow *window = new Danbooru::DanbooruMainWindow();
    window->setObjectName("danbooruMainWindow");
    window->show();

    // Enable HighDPI support
    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);

    return app.exec();
}