/*
 * SPDX-FileCopyrightText: 2015 Luca Beltrame <lbeltrame@kde.org>
 *
 * This file is part of Danbooru Client.
 *
 *SPDX-License-Identifier: GPL-3.0-or-later
 */

#ifndef DANBOORUCONNECTWIDGET_H_INCLUDED
#define DANBOORUCONNECTWIDGET_H_INCLUDED

#include "ui_danbooruconnectwidget.h"

#include <QWidget>

#include <QString>
#include <QVector>

#include <QUrl>

namespace KWallet
{
class Wallet;
}

namespace Danbooru
{

class DanbooruService;

const QMap< QUrl, QString > initBoardSalts();

class DanbooruConnectWidget: public QWidget, public Ui::DanbooruConnectWidget
{
    Q_OBJECT

public:
    explicit DanbooruConnectWidget(QVector<QUrl> urlList,
                                   QWidget *parent = 0);
    ~DanbooruConnectWidget();

    QString username() const;
    QString password() const;
    QUrl boardUrl() const;
    bool isAnonymous() const;
    void setBoards(const QVector<QUrl> &urlList);

private:
    QUrl  m_boardUrl;
    QString m_username;
    QString m_password;
    KWallet::Wallet *m_wallet;
    static const QMap<QUrl, QString> boardSalts;

Q_SIGNALS:
    void connectionEstablished(DanbooruService *service);
    void accepted();
    void rejected();

private Q_SLOTS:
    void checkWallet(bool);
    void getWalletData();
    void toggleLineEdits(int state);
    void accept();
};

} // namespace Danbooru

#endif // DANBOORUCONNECTWIDGET_H_INCLUDED
