/*
 * SPDX-FileCopyrightText: 2015 Luca Beltrame <lbeltrame@kde.org>
 *
 * This file is part of Danbooru Client.
 *
 *SPDX-License-Identifier: GPL-3.0-or-later
 */

#include "danboorusearchwidget.h"

#include <QPushButton>
#include <QLineEdit>

namespace Danbooru
{

DanbooruSearchWidget::DanbooruSearchWidget(QWidget *parent): QWidget(parent)
{
    setupUi(this);

    tagLineEdit->setPlaceholderText(i18n("Type search tags."));
    tagLineEdit->setToolTip(i18n("Type search tags. An empty string searches all posts."));
    widthSpinBox->setSuffix(ki18np(" pixel", " pixels"));
    heightSpinBox->setSuffix(ki18np(" pixel", " pixels"));

    widthSpinBox->setValue(0);
    heightSpinBox->setValue(0);


    connect(searchButton, &QPushButton::clicked, this, &DanbooruSearchWidget::accept);
    connect(tagLineEdit, &QLineEdit::returnPressed, this, &DanbooruSearchWidget::accept);
    connect(closeButton, &QPushButton::clicked, [this]() {
        Q_EMIT(rejected());
    });

}

DanbooruSearchWidget::~DanbooruSearchWidget()
{
}

QStringList DanbooruSearchWidget::selectedTags() const
{
    return m_tags;
}

unsigned int DanbooruSearchWidget::selectedWidth() const
{
    return m_width;
}

unsigned int DanbooruSearchWidget::selectedHeight() const
{
    return m_height;
}


void DanbooruSearchWidget::accept()
{

    m_tags = tagLineEdit->text().split(QStringLiteral(","));
    m_width = widthSpinBox->value();
    m_height = heightSpinBox->value();
    Q_EMIT(accepted());
}

} // namespace Danbooru
