/*
 * SPDX-FileCopyrightText: 2015 Luca Beltrame <lbeltrame@kde.org>
 *
 * This file is part of Danbooru Client.
 *
 *SPDX-License-Identifier: GPL-3.0-or-later
 */

#ifndef DANBOORU_DONMAI_H
#define DANBOORU_DONMAI_H

#include "servicebase.h"
#include "danbooru.h"

class KJob;

namespace Danbooru {

class DanbooruService: public DanbooruServiceBase {

Q_OBJECT

private:
    const QUrl postUri() const override;
    const QUrl poolUri() const override;
    const QUrl artistUri() const override;
    const QUrl tagUri() const override;
    const QUrl poolDataUri() const override;
    const QUrl relatedTagUri() const override;

public:

   using DanbooruServiceBase::DanbooruServiceBase; // superclass constructor

   Danbooru::ApiType apiType() const override;

   void getPostList() override;
   void getPoolList(int limit = -1) override;
   void getPool(int poolId, int page = 1) override;
   void getTagList(int limit = 10, QString name = "") override;
   void getRelatedTags(const QStringList &tags,
                       DanbooruTag::TagType tagType = DanbooruTag::General) override;

private Q_SLOTS:
    void processTagList(KJob *job);
    void downloadAllTags(KJob *job);
    void processSinglePost(KJob *job);

};

} // namespace Danbooru

#endif

