/*
 * SPDX-FileCopyrightText: 2015 Luca Beltrame <lbeltrame@kde.org>
 *
 * This file is part of Danbooru Client.
 *
 *SPDX-License-Identifier: GPL-3.0-or-later
 */

#ifndef DANBOORUPOOL_H
#define DANBOORUPOOL_H

/**
 * @brief This file includes classes which models Danbooru pools.
 * @file danboorupool.h
 *
 **/

// Qt

#include <QObject>
#include <QVariant>
#include <QList>
#include <QStringList>
#include <QXmlStreamAttributes>

namespace Danbooru
{

/**
 * @brief Class representing a Danbooru pool.
 *
 * Pools are organized groups of images, often by a common theme, for
 * example taken from the same artbook. They are identified by unique IDs
 * and are represented by a name, a description, and the posts they
 * contain.
 *
 * @author Luca Beltrame (lbeltrame@kde.org)
 *
 * **/
class DanbooruPool : public QObject
{

    Q_OBJECT

private:
    int m_id;
    int m_postCount;
    QString m_name;
    QString m_description;
    QList<int> m_posts;
public:

    /**
     * @brief Construct a Danbooru pool from a QVariantMap.
     *
     * This form is the easiest to use and should be used when dealing with
     * responses in JSON format. Unfortunately most Danbooru
     * implementations produce broken JSON for some responses.
     *
     * @param postData A QVariantMap from parsed JSON representing the
     *      data from a single pool.
     *
     *
     **/
    DanbooruPool(const QVariantMap &postData, QObject *parent = 0);

    /**
     * @brief Construct a Danbooru pool from a QVariantMap.
     *
     * This form is the easiest to use and should be used when dealing with
     * responses in JSON format. Unfortunately most Danbooru
     * implementations produce broken JSON for some responses.
     *
     * @param postData A QXmlStreamAttributes instance holding the
     *      attributes for the given pool.
     *
     *
     **/
    DanbooruPool(const QXmlStreamAttributes &postData, QObject *parent = 0);

    int id() const;
    int postCount() const;
    QString name() const;
    QString description() const;
    QList<int> posts() const;
    const QVariantList postData() const;

    void addPost(int post);
    void addPosts(QList<int> posts);
};

} // namespace Danbooru

Q_DECLARE_METATYPE(Danbooru::DanbooruPool *)

#endif // DANBOORUPOOL_H
