/*
 * SPDX-FileCopyrightText: 2018 Luca Beltrame <lbeltrame@kde.org>
 *
 * This file is part of Danbooru Client.
 *
 *SPDX-License-Identifier: GPL-3.0-or-later
 */

#include "test_service.h"
#include "../danbooru.h"
#include "../servicebase.h"

#include <QApplication>
#include <QTimer>
#include <QThread>
#include <QCommandLineParser>

void runTest(QUrl apiUrl, Danbooru::ApiType apiType);
void runPostTest();
void runNextPostPageTest();
void runPoolTest();
void runPoolRetrieval();

template<Danbooru::ApiType> class ServiceTest;

Danbooru::DanbooruServiceTest* testSvc = nullptr;

int main(int argc, char *argv[]) {
    QApplication app(argc, argv);

    QCommandLineParser cmdParser;
    cmdParser.addHelpOption();
    cmdParser.addVersionOption();

    QCommandLineOption testKonachan("test-konachan", "Run Konachan.com tests");
    QCommandLineOption testYandeRe("test-yandere", "Run yande.re tests");
    QCommandLineOption testDonmai("test-danbooru", "Run danbooru.donmai.us tests");

    cmdParser.addOptions({testKonachan, testYandeRe, testDonmai});
    cmdParser.process(app);

    if (cmdParser.isSet(testKonachan)) {
        qDebug() << "Starting Konachan.com test";
        runTest(QUrl("http://konachan.net"), Danbooru::MoeBooru);
    } else if (cmdParser.isSet(testYandeRe)) {
        qDebug() << "Starting yande.re test";
        runTest(QUrl("http://yande.re"), Danbooru::MoeBooru);
    } else if (cmdParser.isSet(testDonmai)) {
        runTest(QUrl("http://danbooru.donmai.us"), Danbooru::Danbooru);
    } else {
        cmdParser.showHelp();
    }

    app.exec();
}

void runTest(QUrl apiUrl, Danbooru::ApiType apiType)
{
    testSvc = new Danbooru::DanbooruServiceTest(apiUrl, apiType);
    QObject::connect(testSvc->service(), &Danbooru::DanbooruServiceBase::postDownloadFinished,
                     testSvc, &runNextPostPageTest);

    testSvc->testPostService();
   
    qDebug() << "--- POST TEST ---";
    

}

void runNextPostPageTest()
{
    QObject::disconnect(testSvc->service(), &Danbooru::DanbooruServiceBase::postDownloadFinished,
                        testSvc, 0);
    QObject::connect(testSvc->service(), &Danbooru::DanbooruServiceBase::postDownloadFinished,
                     testSvc, &runPoolTest);
    qDebug() << "--- NEXT POST PAGE TEST ---";
    testSvc->service()->nextPostPage();
}


void runPoolTest()
{
    QObject::disconnect(testSvc->service(), &Danbooru::DanbooruServiceBase::postDownloadFinished,
                        testSvc, 0);
    QObject::connect(testSvc->service(), &Danbooru::DanbooruServiceBase::poolDownloadFinished,
                     testSvc, &runPoolRetrieval);
    testSvc->service()->nextPostPage();
    qDebug() << "--- POOL TEST ---";
    testSvc->testPoolService();
}

void runPoolRetrieval()
{
    QObject::disconnect(testSvc->service(), &Danbooru::DanbooruServiceBase::poolDownloadFinished,
                        testSvc, 0);
    QObject::connect(testSvc->service(), &Danbooru::DanbooruServiceBase::postDownloadFinished,
                        testSvc, [=]() {
                            QThread::sleep(5);
                            QApplication::quit();});
    qDebug() << "--- POOL RETRIEVAL TEST ---";
    testSvc->testPoolRetrieval(300);
}
