/*
 * SPDX-FileCopyrightText: 2015 Luca Beltrame <lbeltrame@kde.org>
 *
 * This file is part of Danbooru Client.
 *
 *SPDX-License-Identifier: GPL-3.0-or-later
 */

#ifndef DANBOORU_CLIENT_H
#define DANBOORU_CLIENT_H

#include "libdanbooru/danboorupost.h"

#include <QTableView>
#include <QListView>

#include <kxmlguiwindow.h>
#include <KSharedDataCache>
#include <KImageCache>

class QQuickWidget;
class QSortFilterProxyModel;

namespace Danbooru
{

class DanbooruClientView;
class DanbooruServiceBase;
class DanbooruPostModel;
class DanbooruPoolModel;
class DanbooruTagModel;
class DanbooruConnectWidget;
class DanbooruSearchWidget;
class DanbooruTagWidget;

/**
 * This class serves as the main window for danbooru_client.  It handles the
 * menus, toolbars and status bars.
 *
 * @short Main window class
 * @author Luca Beltrame <lbeltrame@kde.org>
 * @version 0.01
 */
class DanbooruMainWindow : public KXmlGuiWindow
{
    Q_OBJECT

private:
    QQuickWidget *m_view;
    DanbooruPostModel *m_model;
    DanbooruPoolModel *m_poolModel;
    DanbooruTagModel *m_tagModel;
    DanbooruServiceBase *m_service;
    DanbooruConnectWidget *m_connectWidget;
    DanbooruSearchWidget *m_searchWidget;
    DanbooruTagWidget *m_tagWidget;
    QSortFilterProxyModel *m_proxyModel;

    QTableView *m_tableView;
    KImageCache *m_cache;
    static QHash<int, Danbooru::Rating> ratingMap;

public:
    /**
     * Default Constructor
     */
    DanbooruMainWindow(QWidget *parent = 0);

    /**
     * Default Destructor
     */
    virtual ~DanbooruMainWindow();

private:
    void setupActions();
    void setupDockWidgets();
    void setupConnections();
    void clearModels();
    void handlePostDownload(const QStringList &tags = QStringList(), bool relatedTags = false,
        unsigned int minimumWidth = 0, unsigned int minimumHeight = 0);

private Q_SLOTS:
    void connectToBoard();
    void downloadPosts();
    void optionsPreferences();
    void loadSettings();
    void slotHandleDownload(const QUrl &url, QVariant tags);
    void searchTag(const QModelIndex &index);

};
} // namespace Danbooru

#endif // _DANBOORU_CLIENT_H_
