/*
 * SPDX-FileCopyrightText: 2015 Luca Beltrame <lbeltrame@kde.org>
 *
 * This file is part of Danbooru Client.
 *
 *SPDX-License-Identifier: GPL-3.0-or-later
 */

#include "danboorupoolmodel.h"
#include "libdanbooru/danboorupool.h"

#include "danbooru_client_debug.h"

#include <KLocalizedString>

namespace Danbooru
{

DanbooruPoolModel::DanbooruPoolModel(QObject *parent): QAbstractTableModel(parent)
{
}

const QStringList DanbooruPoolModel::m_headerNames = { i18n("ID"),
                                                       i18n("Name"),
                                                       i18n("Posts"),
                                                       i18n("Description")
                                                     };

DanbooruPoolModel::~DanbooruPoolModel()
{
    if (!m_items.isEmpty()) {
        qDeleteAll(m_items);
        m_items.clear();
    }
}

void DanbooruPoolModel::addPool(DanbooruPool *pool)
{
    beginInsertRows(QModelIndex(), m_items.size(), m_items.size());
    m_items.append(pool);
    endInsertRows();
}

int DanbooruPoolModel::rowCount(const QModelIndex &parent) const
{
    Q_UNUSED(parent)
    return m_items.size();
}

int DanbooruPoolModel::columnCount(const QModelIndex &parent) const
{
    Q_UNUSED(parent)
    return 4;
}

QVariant DanbooruPoolModel::data(const QModelIndex &index, int role) const
{
    if (!index.isValid()) {
        return QVariant();
    }

    if (index.row() >= m_items.size() || index.row() < 0) {
        return QVariant();
    }

    if (m_items.isEmpty()) {
        return QVariant();
    }

    DanbooruPool *pool = m_items.at(index.row());

    if (role == Qt::DisplayRole) {

        if (index.column() == 0) {
            return pool->id();
        } else if (index.column() == 1) {
            return pool->name();
        } else if (index.column() == 2) {
            return pool->postCount();
        } else if (index.column() == 3) {
            return pool->description();
        }
    }

    return QVariant();

}

QVariant DanbooruPoolModel::headerData(int section, Qt::Orientation orientation, int role) const
{
    if (role == Qt::DisplayRole && orientation == Qt::Horizontal) {
        return m_headerNames.at(section);
    }

    return QAbstractTableModel::headerData(section, orientation, role);

}

void DanbooruPoolModel::clear()
{
    if (m_items.isEmpty()) {
        return;
    }

    beginResetModel();
    qDeleteAll(m_items);
    m_items.clear();
    endResetModel();
}

DanbooruPool *DanbooruPoolModel::poolAt(int index) const
{
    return m_items.at(index);
}

} // namespace Danbooru
