/*
 * SPDX-FileCopyrightText: 2015 Luca Beltrame <lbeltrame@kde.org>
 *
 * This file is part of Danbooru Client.
 *
 *SPDX-License-Identifier: GPL-3.0-or-later
 */

#ifndef DANBOORUPOSTMODEL_H
#define DANBOORUPOSTMODEL_H

/**
 * @brief This file contains a specific model to represent Danbooru Items
 * @file danboorutablemodel.h
 *
 **/

#include <QAbstractListModel>
#include <QVector>
#include <QSet>

namespace Danbooru
{

class DanbooruPost;

/**
 * @brief A model to represent DanbooruItems
 *
 * Since items from a Danbooru service are sent by the service itself,
 * there is no need for sorting or table-like structures: everything is
 * represented as a flat list.
 *
 * Items are added through the addPost() slot.
 *
 */
class DanbooruPostModel : public QAbstractListModel
{

    Q_OBJECT

public:
    DanbooruPostModel(QObject *parent = 0);
    ~DanbooruPostModel();

    Q_INVOKABLE int rowCount(const QModelIndex &parent = QModelIndex()) const override;
    QVariant data(const QModelIndex &index, int role) const override;
    void clear();
    QHash<int, QByteArray> roleNames() const override;
    QStringList postTags() const;

    enum PostRoles {
        FileUrlRole = Qt::UserRole + 1001,
        ThumbUrlRole = Qt::UserRole + 1002,
        SizeRole = Qt::UserRole + 1003,
        RatingRole = Qt::UserRole + 1004,
        TagRole = Qt::UserRole + 1005,
        ResolutionRole = Qt::UserRole + 1006,
        SampleUrlRole = Qt::UserRole + 1007
    };

private:
    QVector<DanbooruPost *> m_items;
    QSet<QString> m_postTags;

public Q_SLOTS:
    /**
     * @brief Add a new post to the model
     *
     * Connect to this slot when you want to add items to the model.
     *
     * @param post A pointer to a DanbooruPost.
     *
     */
    void addPost(Danbooru::DanbooruPost *post);

};
} // namespace Danbooru

#endif // DANBOORUPOSTMODEL_H
